==> grit-0.0.5.tgz: package/README.md <==
GRIT
====

Lightweight [Backbone](http://documentcloud.github.com/backbone/)-like models for NodeJS and browsers. For times when
the whole of Backbone seems too hefty.

API
---

The API follows the NodeJS EventEmitter API, and the events emitted are
inspired by Backbone.

* `grit.on(e, handler)`, or `grit.addListener(e, handler)` add an event
handler to the object. Grit objects emit `"change:e"` events, where `e`
is the name of the property being changed.
* `grit.removeListener(e, handler)` removes an event handler.
* `grit.get(property)` gets a named property.
* `grit.set(property, value[, silent])` sets a property. Passing a truthy
value as the `silent` parameter suppresses a change event; otherwise, a
`change:property` event will be emitted, where `property` is the value
passed in as the `property` parameter.
* `grit.validate(property, validator)` adds a validation callback to
a property. Validation callbacks must be of the form `function(value)`,
and the `value` that gets passed in is the new value being set. If
all validators of a property return truthy values, the property will 
successfully be set; otherwise, it won't.
* `grit.sync(model, data, property)` is an empty method, meant to be
overridden. It gets called after any property is changed. `model` is
the Grit object being changed, `data` is a Javascript object with the
model's data inside, and `property` is the name of the property that
was changed.
* `grit.load()` is another empty method. Override it to define how
to load models from the server or DB.

==> grit-0.0.6.tgz: package/README.md <==
GRIT
====

Lightweight [Backbone](http://documentcloud.github.com/backbone/)-like models for NodeJS and browsers. For times when
the whole of Backbone seems too hefty.

API
---

The API follows the NodeJS EventEmitter API, and the events emitted are
inspired by Backbone.

## Instance Methods
* `grit.on(e, handler)`, or `grit.addListener(e, handler)` add an event
handler to the object. Grit objects emit `"change:e"` events, where `e`
is the name of the property being changed.
* `grit.removeListener(e, handler)` removes an event handler.
* `grit.get(property)` gets a named property.
* `grit.set(property, value[, silent])` sets a property. Passing a truthy
value as the `silent` parameter suppresses a change event; otherwise, a
`change:property` event will be emitted, where `property` is the value
passed in as the `property` parameter.
* `grit.sync(model, data, property)` is an empty method, meant to be
overridden. It gets called after any property is changed. `model` is
the Grit object being changed, `data` is a Javascript object with the
model's data inside, and `property` is the name of the property that
was changed.
* `grit.load()` is another empty method. Override it to define how
to load models from the server or DB.

## Class Methods
* `Grit.validate(property, validator)` adds a validation callback to
a property. Validation callbacks must be of the form `function(value)`,
and the `value` that gets passed in is the new value being set. If
all validators of a property return truthy values, the property will 
successfully be set; otherwise, it won't.
* `Grit.extend(constructorFunction)` makes it easy for normal JS classes
to inherit from Grit, or any Grit subclass. Just pass the constructor 
function to `extend`, and don't forget to call `Grit.call(this)` (or
`SubClass.call(this)`) on the first line of the constructor function.
